What you need: python2.7 with numpy, matplotlib, Tkinter, tkFileDialog, tkMessageBox, netCDF4
Special need: GSL library installed, add to LD_LIBRARY_PATH
Make sure everything is in place (PYTHONPATH).

Visual tool to collect TRANSP input (u-files). Recursive cubic-spline for the input profiles.

python trgui.py
More documentation at http://www.ipp.mpg.de/~git/transp/trgui.html
